@@ -1,7 +1,7 @@
 package Perinci::Examples::Bin::Any;
 
-our $DATE = '2014-11-21'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-09-09'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 
@@ -20,20 +20,18 @@ Perinci::Examples::Bin::Any - Perinci example scripts (using Perinci::CmdLine::A
 
 =head1 VERSION
 
-This document describes version 0.05 of Perinci::Examples::Bin::Any (from Perl distribution Perinci-Examples-Bin-Any), released on 2014-11-21.
+This document describes version 0.06 of Perinci::Examples::Bin::Any (from Perl distribution Perinci-Examples-Bin-Any), released on 2015-09-09.
 
 =head1 DESCRIPTION
 
 This distribution contains example scripts in C<bin/> which use
 L<Perinci::CmdLine::Any>.
 
-=head1 FAQ
+=head1 SEE ALSO
 
-=head2 Where are examples using Perinci::CmdLine::Lite?
+L<Perinci::Examples::Bin::Classic>
 
-You can use the scripts in this distribution, and run them with:
-
- % PERINCI_CMDLINE_ANY=Perinci::CmdLine::Lite script ...
+L<Perinci::Examples::Bin::Lite>
 
 =head1 HOMEPAGE
 
@@ -57,7 +55,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
